@@ -2,7 +2,7 @@ package PDF::Tiny;
 
 use 5.01;
 
-$VERSION = '0.06'; # Update the POD, too!
+$VERSION = '0.07'; # Update the POD, too!
 
 # Fields
 sub vers () { 0 }
@@ -257,7 +257,8 @@ sub import_page {
  while (!$temp_copy->[1]{Resources} || !$temp_copy->[1]{MediaBox}
      || !$temp_copy->[1]{CropBox} and $node->[1]{Parent}) {
    $node = $source_pdf->get_obj($node, '/Parent');
-   $node->[1]{$_} and $temp_copy->[1]{$_} = $node->[1]{$_}
+   $node->[1]{$_} and !$temp_copy->[1]{$_}
+                  and  $temp_copy->[1]{$_} = $node->[1]{$_}
      for qw< Resources MediaBox CropBox >;
  }
  delete $temp_copy->[1]{Parent};
